ExpectationNormalizedMetric
===========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ExpectationNormalizedMetric
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ExpectationNormalizedMetric.expected_value
      ~ExpectationNormalizedMetric.get_coefficients

   .. rubric:: Methods Documentation

   .. automethod:: expected_value
   .. automethod:: get_coefficients
